@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Byebug
   #
   # Reopens the +info+ command to define the +breakpoints+ subcommand
@@ -6,13 +8,27 @@ module Byebug
     #
     # Information about current breakpoints
     #
-    class BreakpointsSubcommand < Command
-      def regexp
+    class BreakpointsCommand < Command
+      self.allow_in_post_mortem = true
+
+      def self.regexp
         /^\s* b(?:reakpoints)? (?:\s+ (.+))? \s*$/x
       end
 
+      def self.description
+        <<-DESCRIPTION
+          inf[o] b[reakpoints]
+
+          #{short_description}
+        DESCRIPTION
+      end
+
+      def self.short_description
+        "Status of user settable breakpoints"
+      end
+
       def execute
-        return puts('No breakpoints.') if Byebug.breakpoints.empty?
+        return puts("No breakpoints.") if Byebug.breakpoints.empty?
 
         breakpoints = Byebug.breakpoints.sort_by(&:id)
 
@@ -20,39 +36,31 @@ module Byebug
           indices = @match[1].split(/ +/).map(&:to_i)
           breakpoints = breakpoints.select { |b| indices.member?(b.id) }
           if breakpoints.empty?
-            return errmsg('No breakpoints found among list given')
+            return errmsg("No breakpoints found among list given")
           end
         end
 
-        puts 'Num Enb What'
+        puts "Num Enb What"
         breakpoints.each { |b| info_breakpoint(b) }
       end
 
-      def short_description
-        'Status of user settable breakpoints.'
-      end
-
-      def description
-        <<-EOD
-          inf[o] b[reakpoints]
-
-          #{short_description}
-        EOD
-      end
-
       private
 
       def info_breakpoint(brkpt)
-        expr = brkpt.expr.nil? ? '' : " if #{brkpt.expr}"
-        y_n = brkpt.enabled? ? 'y' : 'n'
-        interp = format('%-3d %-3s at %s:%s%s',
-                        brkpt.id, y_n, brkpt.source, brkpt.pos, expr)
+        interp = format(
+          "%-<id>3d %-<status>3s at %<file>s:%<line>s%<expression>s",
+          id: brkpt.id,
+          status: brkpt.enabled? ? "y" : "n",
+          file: brkpt.source,
+          line: brkpt.pos,
+          expression: brkpt.expr.nil? ? "" : " if #{brkpt.expr}"
+        )
         puts interp
         hits = brkpt.hit_count
         return unless hits > 0
 
-        s = (hits > 1) ? 's' : ''
-        puts "\tbreakpoint already hit #{hits} time#{s}"
+        s = hits > 1 ? "s" : ""
+        puts "  breakpoint already hit #{hits} time#{s}"
       end
     end
   end
