@@ -1,6 +1,8 @@
-require 'byebug/command'
-require 'irb'
-require 'English'
+# frozen_string_literal: true
+
+require "byebug/command"
+require "irb"
+require "English"
 
 module Byebug
   #
@@ -14,20 +16,20 @@ module Byebug
     end
 
     def self.description
-      <<-EOD
+      <<-DESCRIPTION
         irb
 
         #{short_description}
-      EOD
+      DESCRIPTION
     end
 
     def self.short_description
-      'Starts an IRB session'
+      "Starts an IRB session"
     end
 
     def execute
       unless processor.interface.instance_of?(LocalInterface)
-        return errmsg(pr('base.errors.only_local'))
+        return errmsg(pr("base.errors.only_local"))
       end
 
       # @todo IRB tries to parse $ARGV so we must clear it (see #197). Add a
