@@ -1,4 +1,6 @@
-require 'byebug/command'
+# frozen_string_literal: true
+
+require "byebug/command"
 
 module Byebug
   #
@@ -12,17 +14,17 @@ module Byebug
     end
 
     def self.description
-      <<-EOD
+      <<-DESCRIPTION
         kill[ signal]
 
         #{short_description}
 
         Equivalent of Process.kill(Process.pid)
-      EOD
+      DESCRIPTION
     end
 
     def self.short_description
-      'Sends a signal to the current process'
+      "Sends a signal to the current process"
     end
 
     def execute
@@ -33,12 +35,12 @@ module Byebug
           return errmsg("signal name #{signame} is not a signal I know about\n")
         end
       else
-        return unless confirm('Really kill? (y/n) ')
+        return unless confirm("Really kill? (y/n) ")
 
-        signame = 'KILL'
+        signame = "KILL"
       end
 
-      processor.interface.close if signame == 'KILL'
+      processor.interface.close if signame == "KILL"
       Process.kill(signame, Process.pid)
     end
   end
