@@ -1,5 +1,7 @@
-require 'byebug/command'
-require 'byebug/helpers/parse'
+# frozen_string_literal: true
+
+require "byebug/command"
+require "byebug/helpers/parse"
 
 module Byebug
   #
@@ -11,26 +13,28 @@ module Byebug
   class NextCommand < Command
     include Helpers::ParseHelper
 
-    self.allow_in_post_mortem = false
-
-    def regexp
+    def self.regexp
       /^\s* n(?:ext)? (?:\s+(\S+))? \s*$/x
     end
 
-    def execute
-      steps, err = parse_steps(@match[1], 'Next')
-      return errmsg(err) unless steps
-
-      @state.context.step_over(steps, @state.frame)
-      @state.proceed
-    end
-
-    def description
-      <<-EOD
+    def self.description
+      <<-DESCRIPTION
         n[ext][ nnn]
 
-        Steps over once or nnn times.
-      EOD
+        #{short_description}
+      DESCRIPTION
+    end
+
+    def self.short_description
+      "Runs one or more lines of code"
+    end
+
+    def execute
+      steps, err = parse_steps(@match[1], "Next")
+      return errmsg(err) unless steps
+
+      context.step_over(steps, context.frame.pos)
+      processor.proceed!
     end
   end
 end
