@@ -1,4 +1,6 @@
-require 'byebug/command'
+# frozen_string_literal: true
+
+require "byebug/command"
 
 module Byebug
   #
@@ -6,29 +8,35 @@ module Byebug
   #
   class QuitCommand < Command
     self.allow_in_control = true
+    self.allow_in_post_mortem = true
 
-    def regexp
+    def self.regexp
       /^\s* q(?:uit)? \s* (?:(!|\s+unconditionally))? \s*$/x
     end
 
-    def execute
-      return unless @match[1] || confirm(pr('quit.confirmations.really'))
-
-      @state.interface.autosave
-      @state.interface.close
-      exit! # exit -> exit!: No graceful way to stop...
-    end
-
-    def description
-      <<-EOD
+    def self.description
+      <<-DESCRIPTION
         q[uit] [!|unconditionally]
 
-        Exits from byebug.
+        #{short_description}
 
         Normally we prompt before exiting. However if the parameter
         "unconditionally" is given or command is suffixed with !, we exit
         without asking further questions.
-      EOD
+      DESCRIPTION
+    end
+
+    def self.short_description
+      "Exits byebug"
+    end
+
+    def execute
+      return unless @match[1] || confirm(pr("quit.confirmations.really"))
+
+      processor.interface.autosave
+      processor.interface.close
+
+      Process.exit!
     end
   end
 end
