@@ -1,4 +1,6 @@
-require 'byebug/helpers/thread'
+# frozen_string_literal: true
+
+require "byebug/helpers/thread"
 
 module Byebug
   #
@@ -8,13 +10,25 @@ module Byebug
     #
     # Resumes the specified thread
     #
-    class ResumeSubcommand < Command
+    class ResumeCommand < Command
       include Helpers::ThreadHelper
 
-      def regexp
+      def self.regexp
         /^\s* r(?:esume)? (?: \s* (\d+))? \s*$/x
       end
 
+      def self.description
+        <<-DESCRIPTION
+          th[read] r[esume] <thnum>
+
+          #{short_description}
+        DESCRIPTION
+      end
+
+      def self.short_description
+        "Resumes execution of the specified thread"
+      end
+
       def execute
         return puts(help) unless @match[1]
 
@@ -22,24 +36,12 @@ module Byebug
         return errmsg(err) if err
 
         unless context.suspended?
-          return errmsg(pr('thread.errors.already_running'))
+          return errmsg(pr("thread.errors.already_running"))
         end
 
         context.resume
         display_context(context)
       end
-
-      def short_description
-        'Resumes execution of the specified thread'
-      end
-
-      def description
-        <<-EOD
-          th[read] r[esume] <thnum>
-
-          #{short_description}
-        EOD
-      end
     end
   end
 end
