@@ -1,4 +1,6 @@
-require 'byebug/helpers/thread'
+# frozen_string_literal: true
+
+require "byebug/helpers/thread"
 
 module Byebug
   #
@@ -8,13 +10,25 @@ module Byebug
     #
     # Stops the specified thread
     #
-    class StopSubcommand < Command
+    class StopCommand < Command
       include Helpers::ThreadHelper
 
-      def regexp
+      def self.regexp
         /^\s* st(?:op)? (?: \s* (\d+))? \s*$/x
       end
 
+      def self.description
+        <<-DESCRIPTION
+          th[read] st[op] <thnum>
+
+          #{short_description}
+        DESCRIPTION
+      end
+
+      def self.short_description
+        "Stops the execution of the specified thread"
+      end
+
       def execute
         return puts(help) unless @match[1]
 
@@ -24,18 +38,6 @@ module Byebug
         context.suspend
         display_context(context)
       end
-
-      def short_description
-        'Stops the execution of the specified thread'
-      end
-
-      def description
-        <<-EOD
-          th[read] st[op] <thnum>
-
-          #{short_description}
-        EOD
-      end
     end
   end
 end
