@@ -1,4 +1,6 @@
-require 'byebug/helpers/thread'
+# frozen_string_literal: true
+
+require "byebug/helpers/thread"
 
 module Byebug
   #
@@ -8,13 +10,25 @@ module Byebug
     #
     # Switches to the specified thread
     #
-    class SwitchSubcommand < Command
+    class SwitchCommand < Command
       include Helpers::ThreadHelper
 
-      def regexp
+      def self.regexp
         /^\s* sw(?:itch)? (?: \s* (\d+))? \s*$/x
       end
 
+      def self.description
+        <<-DESCRIPTION
+          th[read] sw[itch] <thnum>
+
+          #{short_description}
+        DESCRIPTION
+      end
+
+      def self.short_description
+        "Switches execution to the specified thread"
+      end
+
       def execute
         return puts(help) unless @match[1]
 
@@ -24,19 +38,8 @@ module Byebug
         display_context(context)
 
         context.switch
-        @state.proceed
-      end
 
-      def short_description
-        'Switches execution to the specified thread'
-      end
-
-      def description
-        <<-EOD
-          th[read] sw[itch] <thnum>
-
-          #{short_description}
-        EOD
+        processor.proceed!
       end
     end
   end
