@@ -1,4 +1,6 @@
-require 'byebug/helpers/var'
+# frozen_string_literal: true
+
+require "byebug/helpers/var"
 
 module Byebug
   #
@@ -8,28 +10,30 @@ module Byebug
     #
     # Shows instance variables
     #
-    class InstanceSubcommand < Command
+    class InstanceCommand < Command
       include Helpers::VarHelper
 
-      def regexp
+      self.allow_in_post_mortem = true
+
+      def self.regexp
         /^\s* i(?:nstance)? (?:\s+ (.+))? \s*$/x
       end
 
+      def self.description
+        <<-DESCRIPTION
+          v[ar] i[nstance][ <object>]
+
+          #{short_description}
+        DESCRIPTION
+      end
+
+      def self.short_description
+        "Shows instance variables of self or a specific object."
+      end
+
       def execute
         var_instance(@match[1])
       end
-
-      def short_description
-        'Shows instance variables of self or a specific object.'
-      end
-
-      def description
-        <<-EOD
-          v[ar] i[nstance][ <object>]
-
-          #{short_description}
-        EOD
-      end
     end
   end
 end
