@@ -1,13 +1,15 @@
-require 'byebug/helpers/reflection'
-require 'byebug/byebug'
-require 'byebug/context'
-require 'byebug/breakpoint'
-require 'byebug/interface'
-require 'byebug/processors/script_processor'
-require 'byebug/processors/post_mortem_processor'
-require 'byebug/commands'
-require 'byebug/remote'
-require 'byebug/printers/plain'
+# frozen_string_literal: true
+
+require "byebug/helpers/reflection"
+require "byebug/byebug"
+require "byebug/context"
+require "byebug/breakpoint"
+require "byebug/interface"
+require "byebug/processors/script_processor"
+require "byebug/processors/post_mortem_processor"
+require "byebug/commands"
+require "byebug/remote"
+require "byebug/printers/plain"
 
 #
 # Main debugger's container module. Everything is defined under this module
@@ -21,7 +23,7 @@ module Byebug
   # Configuration file used for startup commands. Default value is .byebugrc
   #
   attr_accessor :init_file
-  self.init_file = '.byebugrc'
+  self.init_file = ".byebugrc"
 
   #
   # Debugger's display expressions
@@ -33,7 +35,7 @@ module Byebug
   # Running mode of the debugger. Can be either:
   #
   # * :attached => Attached to a running program through the `byebug` method.
-  # * :standalone => Started through `bin/byebug` script.
+  # * :standalone => Started through `byebug` script.
   #
   attr_accessor :mode
 
@@ -47,11 +49,16 @@ module Byebug
   # are debugging, in the directory where you invoke byebug.
   #
   def run_init_script
-    rc_dirs.each { |dir| run_rc_file(dir) }
+    rc_dirs.each do |dir|
+      rc_file = File.expand_path(File.join(dir, init_file))
+      next unless File.exist?(rc_file)
+
+      run_rc_file(rc_file)
+    end
   end
 
   def self.load_settings
-    Dir.glob(File.join(__dir__, 'settings', '*.rb')).each do |file|
+    Dir.glob(File.join(__dir__, "settings", "*.rb")).each do |file|
       require file
     end
 
@@ -80,17 +87,10 @@ module Byebug
   #
   # Runs a initialization script file
   #
-  def run_rc_file(base_path)
-    old_interface = Context.interface
+  def run_rc_file(rc_file)
+    interface = ScriptInterface.new(rc_file)
 
-    rc_file = File.expand_path(File.join(base_path, init_file))
-    return unless File.exist?(rc_file)
-
-    Context.interface = ScriptInterface.new(rc_file)
-
-    ScriptProcessor.new(nil).process_commands
-  ensure
-    Context.interface = old_interface
+    ScriptProcessor.new(nil, interface).process_commands
   end
 
   #
@@ -99,7 +99,7 @@ module Byebug
   # @note Files will be loaded in the order specified here.
   #
   def rc_dirs
-    [ENV['HOME'], Dir.pwd].compact.uniq
+    [ENV["HOME"], Dir.pwd].compact.uniq
   end
 end
 
