@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Byebug
   module Helpers
     #
@@ -9,7 +11,7 @@ module Byebug
       # ACamelizedString.
       #
       def camelize(str)
-        str.dup.split(/[_-]/).map(&:capitalize).join('')
+        str.dup.split(/[_-]/).map(&:capitalize).join("")
       end
 
       #
@@ -27,7 +29,7 @@ module Byebug
       # use squiggly heredoc's.
       #
       def deindent(str, leading_spaces: 6)
-        str.gsub(/^ {#{leading_spaces}}/, '')
+        str.gsub(/^ {#{leading_spaces}}/, "")
       end
     end
   end
