@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Byebug
   #
   # Interface class for command execution from script files.
@@ -5,9 +7,10 @@ module Byebug
   class ScriptInterface < Interface
     def initialize(file, verbose = false)
       super()
+      @verbose = verbose
       @input = File.open(file)
-      @output = verbose ? STDOUT : StringIO.new
-      @error = verbose ? STDERR : StringIO.new
+      @output = verbose ? $stdout : StringIO.new
+      @error = $stderr
     end
 
     def read_command(prompt)
@@ -20,7 +23,7 @@ module Byebug
 
     def readline(*)
       while (result = input.gets)
-        output.puts "+ #{result}"
+        output.puts "+ #{result}" if @verbose
         next if result =~ /^\s*#/
         return result.chomp
       end
