@@ -1,16 +1,16 @@
 # frozen_string_literal: true
 
-require 'byebug/setting'
+require "byebug/setting"
 
 module Byebug
   #
   # Setting to customize the verbosity level for stack frames.
   #
   class CallstyleSetting < Setting
-    DEFAULT = 'long'.freeze
+    DEFAULT = "long".freeze
 
     def banner
-      'Set how you want method call parameters to be displayed'
+      "Set how you want method call parameters to be displayed"
     end
 
     def to_s
