@@ -1,4 +1,6 @@
-require 'byebug/setting'
+# frozen_string_literal: true
+
+require "byebug/setting"
 
 module Byebug
   #
@@ -8,7 +10,7 @@ module Byebug
     DEFAULT = 256
 
     def banner
-      'Maximum number of commands that can be stored in byebug history'
+      "Maximum number of commands that can be stored in byebug history"
     end
 
     def to_s
