@@ -1,4 +1,6 @@
-require 'byebug/setting'
+# frozen_string_literal: true
+
+require "byebug/setting"
 
 module Byebug
   #
@@ -8,10 +10,7 @@ module Byebug
     DEFAULT = File.expand_path("#{ENV['HOME'] || '.'}/.byebug_save")
 
     def banner
-      <<-EOB
-        File where save commands saves current settings to. Default:
-        ~/.byebug_save
-      EOB
+      "File where settings are saved to. Default: ~/.byebug_save"
     end
 
     def to_s
